==> ejc-sealm-api-3.0.0-20220129.010215-38-sources.jar: com.ejianc.business.sealm/vo/YzdjVO.java <==
package com.ejianc.business.sealm.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 印章登记
 * 
 * @author generator
 * 
 */
public class YzdjVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long yzsqId; // 印章申请id
    private Long yzlbId; // 印章类别id
    private String yzlbName; // 印章类别名称
    private Long yzjbId; // 印章级别id
    private String yzjbName; // 印章级别名称
    private Long yylxId; // 用印类型id
    private String yylxName; // 用印类型名称
    private String kzzy; // 刻章字样
    private Long ssdwId; // 所属单位id
    private String ssdwName; // 所属单位名称
    private java.lang.Long dqbgrId; // 当前保管人id
    private java.lang.String dqbgrName; // 当前保管人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date kzsjTime; // 刻制时间
    private java.lang.Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date basjTime; // 备案时间
    private Long badwId; // 备案单位id
    private String badwName; // 备案单位名称
    private Long scdwId; // 生产单位id
    private String scdwName; // 生产单位名称
    private java.lang.Integer zt; // 状态，默认0总部在库。1正常发放2外借待归3已销毁
    private String remark; // 备注
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    private java.util.Date beginDate; // 开始日期
    private java.util.Date endDate; // 结束日期
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改人
    private java.lang.String yzbh; // 印章编号
    private java.lang.String kzzyjc; // 刻章字样简称
    private java.lang.Long bzdwId; // 编制单位id
    private java.lang.String bzdwName; // 编制单位名称
    private java.lang.Long gldwId; // 管理单位id
    private java.lang.String gldwName; // 管理单位名称
    private Integer messageFrom; // 数据来源：0投标报名，1资格评审，2投标文件评审
    private Long bidId; // 投标模块id
    private String bidCode; // 投标的单据编码
    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 印章申请id
     */
    public Long getYzsqId() {
        return yzsqId;
    }

    /**
     * 印章申请id
     */
    public void setYzsqId(Long yzsqId) {
        this.yzsqId = yzsqId;
    }
    /**
     * 印章类别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    @ReferDeserialTransfer
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    @ReferDeserialTransfer
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    @ReferDeserialTransfer
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    @ReferDeserialTransfer
    public void setSsdwId(Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 当前保管人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public java.lang.Long getDqbgrId() {
        return dqbgrId;
    }

    /**
     * 当前保管人id
     */
    @ReferDeserialTransfer
    public void setDqbgrId(java.lang.Long dqbgrId) {
        this.dqbgrId = dqbgrId;
    }
    /**
     * 当前保管人名称
     */
    public java.lang.String getDqbgrName() {
        return dqbgrName;
    }

    /**
     * 当前保管人名称
     */
    public void setDqbgrName(java.lang.String dqbgrName) {
        this.dqbgrName = dqbgrName;
    }
    /**
     * 刻制时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻制时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public java.lang.Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(java.lang.Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位名称
     */
    public String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位名称
     */
    public void setBadwName(String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位id
     */
    public Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(String scdwName) {
        this.scdwName = scdwName;
    }
    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁
     */
    public java.lang.Integer getZt() {
        return zt;
    }

    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁
     */
    public void setZt(java.lang.Integer zt) {
        this.zt = zt;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**yzbh
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    /**
     * 印章编号
     */
    public void setYzbh(java.lang.String yzbh) {
        this.yzbh = yzbh;
    }
    /**
     * 刻章字样简称
     */
    public java.lang.String getKzzyjc() {
        return kzzyjc;
    }

    /**
     * 刻章字样简称
     */
    public void setKzzyjc(java.lang.String kzzyjc) {
        this.kzzyjc = kzzyjc;
    }
    /**
     * 编制单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public java.lang.Long getBzdwId() {
        return bzdwId;
    }

    /**
     * 编制单位id
     */
    @ReferDeserialTransfer
    public void setBzdwId(java.lang.Long bzdwId) {
        this.bzdwId = bzdwId;
    }
    /**
     * 编制单位名称
     */
    public java.lang.String getBzdwName() {
        return bzdwName;
    }

    /**
     * 编制单位名称
     */

    public void setBzdwName(java.lang.String bzdwName) {
        this.bzdwName = bzdwName;
    }
    /**
     * 管理单位id
     */
    @ReferDeserialTransfer@ReferSerialTransfer(referCode = "idm-org")
    public java.lang.Long getGldwId() {
        return gldwId;
    }

    /**
     * 管理单位id
     */
    @ReferDeserialTransfer
    public void setGldwId(java.lang.Long gldwId) {
        this.gldwId = gldwId;
    }
    /**
     * 管理单位名称
     */
    public java.lang.String getGldwName() {
        return gldwName;
    }

    /**
     * 管理单位名称
     */
    public void setGldwName(java.lang.String gldwName) {
        this.gldwName = gldwName;
    }

    public Integer getMessageFrom() {
        return messageFrom;
    }

    public void setMessageFrom(Integer messageFrom) {
        this.messageFrom = messageFrom;
    }
    public Long getBidId() {
        return bidId;
    }

    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }
    public String getBidCode() {
        return bidCode;
    }

    public void setBidCode(String bidCode) {
        this.bidCode = bidCode;
    }
}

==> ejc-sealm-api-3.0.0-20230210.024612-133-sources.jar: com.ejianc.business.sealm/vo/YzdjVO.java <==
package com.ejianc.business.sealm.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 印章登记
 * 
 * @author generator
 * 
 */
public class YzdjVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long yzsqId; // 印章申请id
    private Long yzlbId; // 印章类别id
    private String yzlbName; // 印章类别名称
    private Long yzjbId; // 印章级别id
    private String yzjbName; // 印章级别名称
    private Long yylxId; // 用印类型id
    private String yylxName; // 用印类型名称
    private String kzzy; // 刻章字样
    private Long ssdwId; // 所属单位id
    private String ssdwName; // 所属单位名称
    private java.lang.Long dqbgrId; // 当前保管人id
    private java.lang.String dqbgrName; // 当前保管人名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date kzsjTime; // 刻制时间
    private java.lang.Integer baqk; // 备案情况（默认0已备案）,0已备案，1未备案
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date basjTime; // 备案时间
    private Long badwId; // 备案单位id
    private String badwName; // 备案单位名称
    private Long scdwId; // 生产单位id
    private String scdwName; // 生产单位名称
    private java.lang.Integer zt; // 状态，默认0总部在库。1正常发放2外借待归3已销毁
    private String remark; // 备注
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer sfYzsq; // 是否从印章申请同步，默认是0(1:是，0：否)
    private java.util.Date beginDate; // 开始日期
    private java.util.Date endDate; // 结束日期
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改人
    private java.lang.String yzbh; // 印章编号
    private java.lang.String kzzyjc; // 刻章字样简称
    private java.lang.Long bzdwId; // 编制单位id
    private java.lang.String bzdwName; // 编制单位名称
    private java.lang.Long gldwId; // 管理单位id
    private java.lang.String gldwName; // 管理单位名称
    private Integer messageFrom; // 数据来源：0投标报名，1资格评审，2投标文件评审
    private Long bidId; // 投标模块id
    private String bidCode; // 投标的单据编码
    private Integer sjxzfs; // 本条数据新增方式(0：印章登记直接新增，1：从印章申请选择新增)


    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 印章申请id
     */
    public Long getYzsqId() {
        return yzsqId;
    }

    /**
     * 印章申请id
     */
    public void setYzsqId(Long yzsqId) {
        this.yzsqId = yzsqId;
    }
    /**
     * 印章类别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzlbId() {
        return yzlbId;
    }

    /**
     * 印章类别id
     */
    @ReferDeserialTransfer
    public void setYzlbId(Long yzlbId) {
        this.yzlbId = yzlbId;
    }
    /**
     * 印章类别名称
     */
    public String getYzlbName() {
        return yzlbName;
    }

    /**
     * 印章类别名称
     */
    public void setYzlbName(String yzlbName) {
        this.yzlbName = yzlbName;
    }
    /**
     * 印章级别id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYzjbId() {
        return yzjbId;
    }

    /**
     * 印章级别id
     */
    @ReferDeserialTransfer
    public void setYzjbId(Long yzjbId) {
        this.yzjbId = yzjbId;
    }
    /**
     * 印章级别名称
     */
    public String getYzjbName() {
        return yzjbName;
    }

    /**
     * 印章级别名称
     */
    public void setYzjbName(String yzjbName) {
        this.yzjbName = yzjbName;
    }
    /**
     * 用印类型id
     */
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getYylxId() {
        return yylxId;
    }

    /**
     * 用印类型id
     */
    @ReferDeserialTransfer
    public void setYylxId(Long yylxId) {
        this.yylxId = yylxId;
    }
    /**
     * 用印类型名称
     */
    public String getYylxName() {
        return yylxName;
    }

    /**
     * 用印类型名称
     */
    public void setYylxName(String yylxName) {
        this.yylxName = yylxName;
    }
    /**
     * 刻章字样
     */
    public String getKzzy() {
        return kzzy;
    }

    /**
     * 刻章字样
     */
    public void setKzzy(String kzzy) {
        this.kzzy = kzzy;
    }
    /**
     * 所属单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getSsdwId() {
        return ssdwId;
    }

    /**
     * 所属单位id
     */
    @ReferDeserialTransfer
    public void setSsdwId(Long ssdwId) {
        this.ssdwId = ssdwId;
    }
    /**
     * 所属单位名称
     */
    public String getSsdwName() {
        return ssdwName;
    }

    /**
     * 所属单位名称
     */
    public void setSsdwName(String ssdwName) {
        this.ssdwName = ssdwName;
    }
    /**
     * 当前保管人id
     */
    @ReferSerialTransfer(referCode = "idm-user")
    public java.lang.Long getDqbgrId() {
        return dqbgrId;
    }

    /**
     * 当前保管人id
     */
    @ReferDeserialTransfer
    public void setDqbgrId(java.lang.Long dqbgrId) {
        this.dqbgrId = dqbgrId;
    }
    /**
     * 当前保管人名称
     */
    public java.lang.String getDqbgrName() {
        return dqbgrName;
    }

    /**
     * 当前保管人名称
     */
    public void setDqbgrName(java.lang.String dqbgrName) {
        this.dqbgrName = dqbgrName;
    }
    /**
     * 刻制时间
     */
    public java.util.Date getKzsjTime() {
        return kzsjTime;
    }

    /**
     * 刻制时间
     */
    public void setKzsjTime(java.util.Date kzsjTime) {
        this.kzsjTime = kzsjTime;
    }
    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public java.lang.Integer getBaqk() {
        return baqk;
    }

    /**
     * 备案情况（默认0已备案）,0已备案，1未备案
     */
    public void setBaqk(java.lang.Integer baqk) {
        this.baqk = baqk;
    }
    /**
     * 备案时间
     */
    public java.util.Date getBasjTime() {
        return basjTime;
    }

    /**
     * 备案时间
     */
    public void setBasjTime(java.util.Date basjTime) {
        this.basjTime = basjTime;
    }
    /**
     * 备案单位id
     */
    public Long getBadwId() {
        return badwId;
    }

    /**
     * 备案单位id
     */
    public void setBadwId(Long badwId) {
        this.badwId = badwId;
    }
    /**
     * 备案单位名称
     */
    public String getBadwName() {
        return badwName;
    }

    /**
     * 备案单位名称
     */
    public void setBadwName(String badwName) {
        this.badwName = badwName;
    }
    /**
     * 生产单位id
     */
    public Long getScdwId() {
        return scdwId;
    }

    /**
     * 生产单位id
     */
    public void setScdwId(Long scdwId) {
        this.scdwId = scdwId;
    }
    /**
     * 生产单位名称
     */
    public String getScdwName() {
        return scdwName;
    }

    /**
     * 生产单位名称
     */
    public void setScdwName(String scdwName) {
        this.scdwName = scdwName;
    }
    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁
     */
    public java.lang.Integer getZt() {
        return zt;
    }

    /**
     * 状态，默认0总部在库。1正常发放2外借待归3已销毁
     */
    public void setZt(java.lang.Integer zt) {
        this.zt = zt;
    }
    /**
     * 备注
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 备注
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }
    /**
     * 组织id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织id
     */
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public Integer getSfYzsq() {
        return sfYzsq;
    }

    /**
     * 是否从印章申请同步，默认是0(1:是，0：否)
     */
    public void setSfYzsq(Integer sfYzsq) {
        this.sfYzsq = sfYzsq;
    }
    /**
     * 开始日期
     */
    public java.util.Date getBeginDate() {
        return beginDate;
    }

    /**
     * 开始日期
     */
    public void setBeginDate(java.util.Date beginDate) {
        this.beginDate = beginDate;
    }
    /**
     * 结束日期
     */
    public java.util.Date getEndDate() {
        return endDate;
    }

    /**
     * 结束日期
     */
    public void setEndDate(java.util.Date endDate) {
        this.endDate = endDate;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 编制人
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 编制人
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 修改人
     */
    public String getUpdateUserName() {
        return updateUserName;
    }

    /**yzbh
     * 修改人
     */
    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }

    /**
     * 印章编号
     */
    public java.lang.String getYzbh() {
        return yzbh;
    }
    public void setYzbh(java.lang.String yzbh) {
        this.yzbh = yzbh;
    }
    /**
     * 刻章字样简称
     */
    public java.lang.String getKzzyjc() {
        return kzzyjc;
    }

    /**
     * 刻章字样简称
     */
    public void setKzzyjc(java.lang.String kzzyjc) {
        this.kzzyjc = kzzyjc;
    }
    /**
     * 编制单位id
     */
    @ReferSerialTransfer(referCode = "idm-org")
    public java.lang.Long getBzdwId() {
        return bzdwId;
    }

    /**
     * 编制单位id
     */
    @ReferDeserialTransfer
    public void setBzdwId(java.lang.Long bzdwId) {
        this.bzdwId = bzdwId;
    }
    /**
     * 编制单位名称
     */
    public java.lang.String getBzdwName() {
        return bzdwName;
    }

    /**
     * 编制单位名称
     */

    public void setBzdwName(java.lang.String bzdwName) {
        this.bzdwName = bzdwName;
    }
    /**
     * 管理单位id
     */
    @ReferDeserialTransfer@ReferSerialTransfer(referCode = "idm-org")
    public java.lang.Long getGldwId() {
        return gldwId;
    }

    /**
     * 管理单位id
     */
    @ReferDeserialTransfer
    public void setGldwId(java.lang.Long gldwId) {
        this.gldwId = gldwId;
    }
    /**
     * 管理单位名称
     */
    public java.lang.String getGldwName() {
        return gldwName;
    }

    /**
     * 管理单位名称
     */
    public void setGldwName(java.lang.String gldwName) {
        this.gldwName = gldwName;
    }

    public Integer getMessageFrom() {
        return messageFrom;
    }

    public void setMessageFrom(Integer messageFrom) {
        this.messageFrom = messageFrom;
    }
    public Long getBidId() {
        return bidId;
    }

    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }
    public String getBidCode() {
        return bidCode;
    }

    public void setBidCode(String bidCode) {
        this.bidCode = bidCode;
    }
    public Integer getSjxzfs() {
        return sjxzfs;
    }

    public void setSjxzfs(Integer sjxzfs) {
        this.sjxzfs = sjxzfs;
    }
}
